@@ -11,7 +11,13 @@ from metricflow.cli.main import _print_issues
 from metricflow.model.parsing.config_linter import ConfigLinter
 from metricflow.model.validations.validator_helpers import ModelValidationResults
 
-EXPECTED_TF_CONFIG_FILE_NAMES = ["tdfconfig.yml", "tdfconfig.yaml", "validate_configs.yaml", "commit_configs.yaml"]
+EXPECTED_TF_CONFIG_FILE_NAMES = [
+    "tdfconfig.yml",
+    "tdfconfig.yaml",
+    "validate_configs.yaml",
+    "commit_configs.yaml",
+    "bitbucket-pipelines.yml",
+]
 TRANSFORM_API_URL = "https://api.transformdata.io"
 UPLOAD_MODE_VALIDATE = "validate"
 UPLOAD_MODE_COMMIT = "commit"
@@ -294,7 +300,12 @@ if __name__ == "__main__":
 
     # Retrieve git info and API key from env
     REPO = os.getenv("REPO")
-    # remove github org from repo
+
+    # Check for BitBucket Repo
+    if not REPO:
+        REPO = os.getenv("BITBUCKET_REPO_FULL_NAME")
+
+    # Remove Github/BitBucket org from repo
     if REPO:
         REPO = "/".join(REPO.split("/")[1:])
 
@@ -303,11 +314,18 @@ if __name__ == "__main__":
         github_ref = os.getenv("GITHUB_REF")
         if github_ref:
             BRANCH = github_ref.lstrip("/refs/heads/")
+    elif os.getenv("BITBUCKET_BRANCH"):
+        # Check in case of BitBucket Branch
+        BRANCH = os.getenv("BITBUCKET_BRANCH")
     else:
         BRANCH = os.getenv("GITHUB_HEAD_REF")
 
     API_URL = os.getenv("TRANSFORM_API_URL", TRANSFORM_API_URL)
+
     COMMIT = os.getenv("GITHUB_SHA")
+    if not COMMIT:
+        COMMIT = os.getenv("BITBUCKET_COMMIT")
+
     TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR")
     if TRANSFORM_CONFIG_DIR:
         TRANSFORM_CONFIG_DIR = TRANSFORM_CONFIG_DIR.lstrip().rstrip()
